<template>
    <div class="app-container">
        <div class="filter-container">
            <div class="carrier_search">
                <span>地区名称：</span>
                <el-input v-model="listQuery.filter.city" class="carrier_search_input"></el-input>
            </div>

            <div class="carrier_search">
                <span>创建日期：</span>
                <el-date-picker
                    v-model="listQuery.filter.starttime"
                    align="right"
                    value-format="yyyy-MM-dd"
                    placeholder="开始时间"
                    :picker-options="pickerOptions">
                </el-date-picker>
                <el-date-picker
                    v-model="listQuery.filter.endtime"
                    align="right"
                    value-format="yyyy-MM-dd"
                    placeholder="结束时间"
                    :picker-options="pickerOptions">
                </el-date-picker>
            </div>
            <el-button  style="margin-left: 10px;" type="primary"  @click="searchData()">查询</el-button>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="licenseStatisticList"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="地区" prop="name" align="center"  >
                </el-table-column>
                <el-table-column label="已过期" prop="expired" align="center">
                </el-table-column>
                <el-table-column label="已审批" prop="reviewed" align="center"  >
                </el-table-column>
                <el-table-column label="待审批" prop="pending" align="center"  >
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
    </div>
</template>

<script>

import {getLicenseStatistic,} from "@/api/license";
import Cookies from "js-cookie";
import { computePageCount } from '../../utils'


export default {
    name: "licenseStatistic",
    data(){
        return{
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            tableKey:0,
            isSupervision:'',
            roleType:'',
            dataForm:{
                city:'',
                expired:'',
                reviewed:'',
                pending:'',
            },
            listQuery:{
                filter:{
                  city:"",
                  starttime:'',
                  endtime:'',
                },
                pageIndex:1,
                pageSize:10,
            },
            licenseStatisticList:[],
            pickerOptions:{
            //     disabledDate(time) {
            //       return time.getTime() > Date.now();
            // },

          }

        }
    },
    components:{
    },
    created(){
      this.getTimeFn()
      this.getLicenseStatistic()
},
    methods:{
      async getLicenseStatistic() {
        this.isSupervision = Cookies.get('isSupervision')
        this.roleType = Cookies.get('roleType')

        this.listLoading = true
        this.listQuery.filter.starttime = this.listQuery.filter.starttime.split(' ')[0] + ' 00:00:00'
        this.listQuery.filter.endtime = this.listQuery.filter.endtime.split(' ')[0] + ' 23:59:59'
        let res = await getLicenseStatistic(this.listQuery)
        if (res.data.code === '200') {
          this.recordTotal = res.data.result.total
          this.pageSize = res.data.result.size
          this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
          this.currentPage = res.data.result.current
          this.licenseStatisticList = res.data.result.records
        }
        this.listLoading = false
      },

      searchData() {
        this.getLicenseStatistic()
      },
      handleSizeChange: function(val) {
        this.listQuery.pageSize = val
        this.getLicenseStatistic()
      },
      handleCurrentChange: function(val) {
        this.listQuery.pageIndex = val
        this.getLicenseStatistic()
      },
      getTimeFn() {
        const that = this
        const end = new Date()
        const start = new Date()
        start.setTime(start.getTime() - 3600 * 1000 * 24 * 7)
        that.listQuery.filter.starttime = start.getFullYear() + '-' + (start.getMonth() +1) + '-' + start.getDate()
        that.listQuery.filter.endtime = end.getFullYear() + '-' + (end.getMonth() +1) + '-' + end.getDate()
      },
    }
}
</script>

<style scoped>
.carrier_search{
    display: inline-block;
}
.carrier_search_input{
    width:200px;
}
</style>
